# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
⬆️ Upgrade to lndb_setup 0.4.0 | [4](https://github.com/laminlabs/lndb-hub/pull/4) | [falexwolf](https://github.com/falexwolf) | 2022-08-01 | 0.3.0
🚚 Rename load to load.entity | [3](https://github.com/laminlabs/lndb-hub/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-01 | 0.2.1
⬆️ Upgrade to lndb-schema-core v0.2.0 | [2](https://github.com/laminlabs/lndb-hub/pull/2) | [falexwolf](https://github.com/falexwolf) | 2022-07-29 | 0.2.0
🚚 Move the code from lamindb here | [1](https://github.com/laminlabs/lndb-hub/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-29 | 0.1.0
